summaryrefslogtreecommitdiffstats
path: root/klipper
diff options
context:
space:
mode:
Diffstat (limited to 'klipper')
-rw-r--r--klipper/applet.cpp2
-rw-r--r--klipper/clipboardpoll.h2
-rw-r--r--klipper/configdialog.cpp24
-rw-r--r--klipper/configdialog.h14
-rw-r--r--klipper/history.h2
-rw-r--r--klipper/historyitem.cpp2
-rw-r--r--klipper/historyurlitem.cpp2
-rw-r--r--klipper/klipperbindings.cpp4
-rw-r--r--klipper/klipperpopup.cpp6
-rw-r--r--klipper/popupproxy.cpp10
-rw-r--r--klipper/popupproxy.h2
-rw-r--r--klipper/toplevel.cpp40
-rw-r--r--klipper/toplevel.h4
-rw-r--r--klipper/urlgrabber.cpp10
-rw-r--r--klipper/urlgrabber.h6
15 files changed, 65 insertions, 65 deletions
diff --git a/klipper/applet.cpp b/klipper/applet.cpp
index 97eee6eec..24b5b6a34 100644
--- a/klipper/applet.cpp
+++ b/klipper/applet.cpp
@@ -91,7 +91,7 @@ void KlipperApplet::preferences()
void KlipperApplet::help()
{
- kapp->invokeHelp(TQString::null, TQString::fromLatin1("klipper"));
+ kapp->invokeHelp(TQString::null, TQString::tqfromLatin1("klipper"));
}
void KlipperApplet::about()
diff --git a/klipper/clipboardpoll.h b/klipper/clipboardpoll.h
index 462ad8097..f0579a4cb 100644
--- a/klipper/clipboardpoll.h
+++ b/klipper/clipboardpoll.h
@@ -26,7 +26,7 @@
#include <fixx11h.h>
class ClipboardPoll
- : public QWidget
+ : public TQWidget
{
Q_OBJECT
public:
diff --git a/klipper/configdialog.cpp b/klipper/configdialog.cpp
index 3f325d40e..73df8dd26 100644
--- a/klipper/configdialog.cpp
+++ b/klipper/configdialog.cpp
@@ -66,7 +66,7 @@ void ConfigDialog::show()
{
if ( !isVisible() ) {
KWinModule module(0, KWinModule::INFO_DESKTOP);
- TQSize s1 = sizeHint();
+ TQSize s1 = tqsizeHint();
TQSize s2 = module.workArea().size();
int w = s1.width();
int h = s1.height();
@@ -203,8 +203,8 @@ void ListView::rename( TQListViewItem* item, int c )
if ( gui ) {
if ( ! _regExpEditor )
- _regExpEditor = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>( "KRegExpEditor/KRegExpEditor", TQString::null, this );
- KRegExpEditorInterface *iface = static_cast<KRegExpEditorInterface *>( _regExpEditor->qt_cast( "KRegExpEditorInterface" ) );
+ _regExpEditor = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>( "KRegExpEditor/KRegExpEditor", TQString(), TQT_TQOBJECT(this) );
+ KRegExpEditorInterface *iface = static_cast<KRegExpEditorInterface *>( _regExpEditor->tqqt_cast( "KRegExpEditorInterface" ) );
assert( iface );
iface->setRegExp( item->text( 0 ) );
@@ -299,13 +299,13 @@ ActionWidget::ActionWidget( const ActionList *list, ConfigDialog* configWidget,
connect( delActionButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotDeleteAction() ));
TQLabel *label = new TQLabel(i18n("Click on a highlighted item's column to change it. \"%s\" in a command will be replaced with the clipboard contents."), box);
- label->setAlignment( WordBreak | AlignLeft | AlignVCenter );
+ label->tqsetAlignment( WordBreak | AlignLeft | AlignVCenter );
box->setStretchFactor( label, 5 );
box = new TQHBox( this );
TQPushButton *advanced = new TQPushButton( i18n("Advanced..."), box );
- advanced->setFixedSize( advanced->sizeHint() );
+ advanced->setFixedSize( advanced->tqsizeHint() );
connect( advanced, TQT_SIGNAL( clicked() ), TQT_SLOT( slotAdvanced() ));
(void) new TQWidget( box ); // spacer
@@ -331,14 +331,14 @@ void ActionWidget::slotContextMenu( KListView *, TQListViewItem *item,
KPopupMenu *menu = new KPopupMenu;
addCmd = menu->insertItem( i18n("Add Command") );
rmCmd = menu->insertItem( i18n("Remove Command") );
- if ( !item->parent() ) {// no "command" item
+ if ( !item->tqparent() ) {// no "command" item
menu->setItemEnabled( rmCmd, false );
item->setOpen( true );
}
int id = menu->exec( pos );
if ( id == addCmd ) {
- TQListViewItem *p = item->parent() ? item->parent() : item;
+ TQListViewItem *p = item->tqparent() ? item->tqparent() : item;
TQListViewItem *cmdItem = new TQListViewItem( p, item,
i18n("Click here to set the command to be executed"),
i18n("<new command>") );
@@ -352,7 +352,7 @@ void ActionWidget::slotContextMenu( KListView *, TQListViewItem *item,
void ActionWidget::slotItemChanged( TQListViewItem *item, const TQPoint&, int col )
{
- if ( !item->parent() || col != 0 )
+ if ( !item->tqparent() || col != 0 )
return;
ClipCommand command( item->text(0), item->text(1) );
item->setPixmap( 0, SmallIcon( command.pixmap.isEmpty() ?
@@ -371,8 +371,8 @@ void ActionWidget::slotAddAction()
void ActionWidget::slotDeleteAction()
{
TQListViewItem *item = listView->currentItem();
- if ( item && item->parent() )
- item = item->parent();
+ if ( item && item->tqparent() )
+ item = item->tqparent();
delete item;
}
@@ -410,8 +410,8 @@ void ActionWidget::slotAdvanced()
AdvancedWidget *widget = new AdvancedWidget( box );
widget->setWMClasses( m_wmClasses );
- dlg.resize( dlg.sizeHint().width(),
- dlg.sizeHint().height() +40); // or we get an ugly scrollbar :(
+ dlg.resize( dlg.tqsizeHint().width(),
+ dlg.tqsizeHint().height() +40); // or we get an ugly scrollbar :(
if ( dlg.exec() == TQDialog::Accepted ) {
m_wmClasses = widget->wmClasses();
diff --git a/klipper/history.h b/klipper/history.h
index befdd164e..405041e0e 100644
--- a/klipper/history.h
+++ b/klipper/history.h
@@ -30,7 +30,7 @@ class TQPopupMenu;
class TQWidget;
class QptrListIterator;
-class History : public QObject
+class History : public TQObject
{
Q_OBJECT
public:
diff --git a/klipper/historyitem.cpp b/klipper/historyitem.cpp
index 481339b30..b217bdb31 100644
--- a/klipper/historyitem.cpp
+++ b/klipper/historyitem.cpp
@@ -52,7 +52,7 @@ HistoryItem* HistoryItem::create( const TQMimeSource& aSource )
TQMap<TQString,TQString> metaData;
if( KURLDrag::decode( &aSource, urls, metaData )) {
// this is from KonqDrag (libkonq)
- TQByteArray a = aSource.encodedData( "application/x-kde-cutselection" );
+ TQByteArray a = aSource.tqencodedData( "application/x-kde-cutselection" );
bool cut = !a.isEmpty() && (a.at(0) == '1'); // true if 1
return new HistoryURLItem( urls, metaData, cut );
}
diff --git a/klipper/historyurlitem.cpp b/klipper/historyurlitem.cpp
index 863a93fb8..18fd72536 100644
--- a/klipper/historyurlitem.cpp
+++ b/klipper/historyurlitem.cpp
@@ -56,7 +56,7 @@ bool HistoryURLItem::operator==( const HistoryItem& rhs) const
if ( const HistoryURLItem* casted_rhs = dynamic_cast<const HistoryURLItem*>( &rhs ) ) {
return casted_rhs->urls == urls
&& casted_rhs->metaData.count() == metaData.count()
- && qEqual( casted_rhs->metaData.begin(), casted_rhs->metaData.end(), metaData.begin())
+ && tqEqual( casted_rhs->metaData.begin(), casted_rhs->metaData.end(), metaData.begin())
&& casted_rhs->cut == cut;
}
return false;
diff --git a/klipper/klipperbindings.cpp b/klipper/klipperbindings.cpp
index 31bb25049..7029d4411 100644
--- a/klipper/klipperbindings.cpp
+++ b/klipper/klipperbindings.cpp
@@ -19,10 +19,10 @@
*/
#ifndef NOSLOTS
# define DEF( name, key3, key4, fnSlot ) \
- keys->insert( name, i18n(name), TQString::null, key3, key4, this, TQT_SLOT(fnSlot) )
+ keys->insert( name, i18n(name), TQString(), key3, key4, TQT_TQOBJECT(this), TQT_SLOT(fnSlot) )
#else
# define DEF( name, key3, key4, fnSlot ) \
- keys->insert( name, i18n(name), TQString::null, key3, key4 )
+ keys->insert( name, i18n(name), TQString(), key3, key4 )
#endif
#define WIN KKey::QtWIN
diff --git a/klipper/klipperpopup.cpp b/klipper/klipperpopup.cpp
index 954768fc5..a064fe87f 100644
--- a/klipper/klipperpopup.cpp
+++ b/klipper/klipperpopup.cpp
@@ -146,7 +146,7 @@ void KlipperPopup::buildFromScratch() {
m_filterWidget = new KLineEditBlackKey( this, "Klipper filter widget" );
insertTitle( SmallIcon( "klipper" ), i18n("Klipper - Clipboard Tool"));
m_filterWidgetId = insertItem( m_filterWidget, m_filterWidgetId, 1 );
- m_filterWidget->setFocusPolicy( TQWidget::NoFocus );
+ m_filterWidget->setFocusPolicy( TQ_NoFocus );
setItemVisible( m_filterWidgetId, false );
m_filterWidget->hide();
TQString lastGroup;
@@ -225,11 +225,11 @@ void KlipperPopup::keyPressEvent( TQKeyEvent* e ) {
// If alt-something is pressed, select a shortcut
// from the menu. Do this by sending a keyPress
// without the alt-modifier to the superobject.
- if ( e->state() & Qt::AltButton ) {
+ if ( e->state() & AltButton ) {
TQKeyEvent ke( TQEvent::KeyPress,
e->key(),
e->ascii(),
- e->state() ^ Qt::AltButton,
+ e->state() ^ AltButton,
e->text(),
e->isAutoRepeat(),
e->count() );
diff --git a/klipper/popupproxy.cpp b/klipper/popupproxy.cpp
index 196a4259c..38e6a1e16 100644
--- a/klipper/popupproxy.cpp
+++ b/klipper/popupproxy.cpp
@@ -94,12 +94,12 @@ void PopupProxy::tryInsertItem( HistoryItem const * const item,
// Squeeze text strings so that do not take up the entire screen (or more)
TQString text( KStringHandler::cPixelSqueeze(item->text().simplifyWhiteSpace(),
proxy_for_menu->fontMetrics(),
- m_menu_width).replace( "&", "&&" ) );
+ m_menu_width).tqreplace( "&", "&&" ) );
id = proxy_for_menu->insertItem( text, -1, index );
} else {
const TQSize max_size( m_menu_width,m_menu_height/4 );
if ( image.height() > max_size.height() || image.width() > max_size.width() ) {
- image.convertFromImage( image.convertToImage().smoothScale( max_size, TQImage::ScaleMin ) );
+ image.convertFromImage( TQImage(image.convertToImage()).smoothScale( max_size, TQ_ScaleMin ) );
}
id = proxy_for_menu->insertItem( image, -1, index );
}
@@ -107,9 +107,9 @@ void PopupProxy::tryInsertItem( HistoryItem const * const item,
// Determine height of a menu item.
Q_ASSERT( id != -1 ); // Be sure that the item was inserted.
- TQMenuItem* mi = proxy_for_menu->findItem( id );
+ TQMenuItem* mi = proxy_for_menu->tqfindItem( id );
int fontheight = TQFontMetrics( proxy_for_menu->fontMetrics() ).height();
- int itemheight = proxy_for_menu->style().sizeFromContents(TQStyle::CT_PopupMenuItem,
+ int itemheight = proxy_for_menu->tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem,
proxy_for_menu,
TQSize( 0, fontheight ),
TQStyleOption(mi,10,0) ).height();
@@ -133,7 +133,7 @@ int PopupProxy::insertFromSpill( int index ) {
// discarding any that doesn't match the current filter.
// stop when the total number of items equal m_itemsPerMenu;
int count = 0;
- int remainingHeight = m_menu_height - proxy_for_menu->sizeHint().height();
+ int remainingHeight = m_menu_height - proxy_for_menu->tqsizeHint().height();
// Force at least one item to be inserted.
remainingHeight = QMAX( remainingHeight, 0 );
for ( const HistoryItem* item = spillPointer.current();
diff --git a/klipper/popupproxy.h b/klipper/popupproxy.h
index 88436cc93..78dbbdc09 100644
--- a/klipper/popupproxy.h
+++ b/klipper/popupproxy.h
@@ -35,7 +35,7 @@ class KlipperPopup;
* Proxy helper for the "more" menu item
*
*/
-class PopupProxy : public QObject
+class PopupProxy : public TQObject
{
Q_OBJECT
diff --git a/klipper/toplevel.cpp b/klipper/toplevel.cpp
index 8b2bcb0eb..b91b5deb0 100644
--- a/klipper/toplevel.cpp
+++ b/klipper/toplevel.cpp
@@ -142,7 +142,7 @@ KlipperWidget::KlipperWidget( TQWidget *parent, KConfig* config )
updateTimestamp(); // read initial X user time
setBackgroundMode( X11ParentRelative );
- clip = kapp->clipboard();
+ clip = kapp->tqclipboard();
connect( &m_overflowClearTimer, TQT_SIGNAL( timeout()), TQT_SLOT( slotClearOverflow()));
m_overflowClearTimer.start( 1000 );
@@ -159,7 +159,7 @@ KlipperWidget::KlipperWidget( TQWidget *parent, KConfig* config )
clearHistoryAction = new KAction( i18n("C&lear Clipboard History"),
"history_clear",
0,
- history(),
+ TQT_TQOBJECT(history()),
TQT_SLOT( slotClear() ),
collection,
"clearHistoryAction" );
@@ -168,7 +168,7 @@ KlipperWidget::KlipperWidget( TQWidget *parent, KConfig* config )
configureAction = new KAction( i18n("&Configure Klipper..."),
"configure",
0,
- this,
+ TQT_TQOBJECT(this),
TQT_SLOT( slotConfigure() ),
collection,
"configureAction" );
@@ -176,7 +176,7 @@ KlipperWidget::KlipperWidget( TQWidget *parent, KConfig* config )
quitAction = new KAction( i18n("&Quit"),
"exit",
0,
- this,
+ TQT_TQOBJECT(this),
TQT_SLOT( slotQuit() ),
collection,
"quitAction" );
@@ -206,7 +206,7 @@ KlipperWidget::KlipperWidget( TQWidget *parent, KConfig* config )
m_iconOrigHeight = height();
adjustSize();
- globalKeys = new KGlobalAccel(this);
+ globalKeys = new KGlobalAccel(TQT_TQOBJECT(this));
KGlobalAccel* keys = globalKeys;
#include "klipperbindings.cpp"
// the keys need to be read from kdeglobals, not kickerrc --ellis, 22/9/02
@@ -283,7 +283,7 @@ void KlipperWidget::clearClipboardHistory()
void KlipperWidget::mousePressEvent(TQMouseEvent *e)
{
- if ( e->button() != LeftButton && e->button() != RightButton )
+ if ( e->button() != Qt::LeftButton && e->button() != Qt::RightButton )
return;
// if we only hid the menu less than a third of a second ago,
@@ -327,7 +327,7 @@ void KlipperWidget::showPopupMenu( TQPopupMenu *menu )
{
Q_ASSERT( menu != 0L );
- TQSize size = menu->sizeHint(); // geometry is not valid until it's shown
+ TQSize size = menu->tqsizeHint(); // geometry is not valid until it's shown
if (bPopupAtMouse) {
TQPoint g = TQCursor::pos();
if ( size.height() < g.y() )
@@ -369,7 +369,7 @@ bool KlipperWidget::loadHistory() {
}
}
if ( !history_file.open( IO_ReadOnly ) ) {
- kdWarning() << failed_load_warning << ": " << history_file.errorString() << endl;
+ kdWarning() << failed_load_warning << ": " << TQString(history_file.errorString()) << endl;
return false;
}
TQDataStream file_stream( &history_file );
@@ -380,10 +380,10 @@ bool KlipperWidget::loadHistory() {
TQDataStream* history_stream = &file_stream;
TQByteArray data;
if( !oldfile ) {
- Q_UINT32 crc;
+ TQ_UINT32 crc;
file_stream >> crc >> data;
if( crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() ) != crc ) {
- kdWarning() << failed_load_warning << ": " << history_file.errorString() << endl;
+ kdWarning() << failed_load_warning << ": " << TQString(history_file.errorString()) << endl;
return false;
}
@@ -444,7 +444,7 @@ void KlipperWidget::saveHistory() {
for ( const HistoryItem* item = history()->first(); item; item = history()->next() ) {
history_stream << item;
}
- Q_UINT32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
+ TQ_UINT32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
*history_file.dataStream() << crc << data;
}
@@ -786,8 +786,8 @@ bool KlipperWidget::blockFetchingNewData()
// contents, so in practice it's like the user has selected only the part which was
// selected when Klipper asked first.
ButtonState buttonstate = kapp->keyboardMouseState();
- if( ( buttonstate & ( ShiftButton | LeftButton )) == ShiftButton // #85198
- || ( buttonstate & LeftButton ) == LeftButton ) { // #80302
+ if( ( buttonstate & ( ShiftButton | Qt::LeftButton )) == ShiftButton // #85198
+ || ( buttonstate & Qt::LeftButton ) == Qt::LeftButton ) { // #80302
m_pendingContentsCheck = true;
m_pendingCheckTimer.start( 100, true );
return true;
@@ -856,7 +856,7 @@ void KlipperWidget::checkClipData( bool selectionMode )
qDebug( " format: %s", format);
}
#endif
- TQMimeSource* data = clip->data( selectionMode ? QClipboard::Selection : QClipboard::Clipboard );
+ TQMimeSource* data = clip->data( selectionMode ? TQClipboard::Selection : TQClipboard::Clipboard );
if ( !data ) {
kdWarning("No data in clipboard. This not not supposed to happen." );
return;
@@ -1013,13 +1013,13 @@ TQString KlipperWidget::getClipboardHistoryItem(int i)
//
bool KlipperWidget::ignoreClipboardChanges() const
{
- TQWidget *focusWidget = qApp->focusWidget();
- if ( focusWidget )
+ TQWidget *tqfocusWidget = tqApp->tqfocusWidget();
+ if ( tqfocusWidget )
{
- if ( focusWidget->inherits( "QSpinBox" ) ||
- (focusWidget->parentWidget() &&
- focusWidget->inherits("QLineEdit") &&
- focusWidget->parentWidget()->inherits("QSpinWidget")) )
+ if ( tqfocusWidget->inherits( "QSpinBox" ) ||
+ (tqfocusWidget->tqparentWidget() &&
+ tqfocusWidget->inherits("QLineEdit") &&
+ tqfocusWidget->tqparentWidget()->inherits("QSpinWidget")) )
{
return true;
}
diff --git a/klipper/toplevel.h b/klipper/toplevel.h
index 7502e4c46..024fb87f7 100644
--- a/klipper/toplevel.h
+++ b/klipper/toplevel.h
@@ -29,7 +29,7 @@
#include <dcopobject.h>
#include <tqtimer.h>
-class QClipboard;
+class TQClipboard;
class KToggleAction;
class KAboutData;
class URLGrabber;
@@ -158,7 +158,7 @@ private slots:
private:
- QClipboard *clip;
+ TQClipboard *clip;
TQTime *hideTimer;
TQTime *showTimer;
diff --git a/klipper/urlgrabber.cpp b/klipper/urlgrabber.cpp
index c814508c1..43640d691 100644
--- a/klipper/urlgrabber.cpp
+++ b/klipper/urlgrabber.cpp
@@ -224,8 +224,8 @@ void URLGrabber::slotItemSelected( int id )
emit sigDisablePopup();
break;
default:
- ClipCommand *command = myCommandMapper.find( id );
- TQStringList *backrefs = myGroupingMapper.find( id );
+ ClipCommand *command = myCommandMapper.tqfind( id );
+ TQStringList *backrefs = myGroupingMapper.tqfind( id );
if ( !command || !backrefs )
qWarning("Klipper: can't find associated action");
else
@@ -365,7 +365,7 @@ bool URLGrabber::isAvoidedWindow() const
&unused, &data_ret ) == Success) {
if ( type_ret == XA_STRING && format_ret == 8 && nitems_ret > 0 ) {
wmClass = TQString::fromUtf8( (const char *) data_ret );
- ret = (myAvoidWindows.find( wmClass ) != myAvoidWindows.end());
+ ret = (myAvoidWindows.tqfind( wmClass ) != myAvoidWindows.end());
}
XFree( data_ret );
@@ -379,7 +379,7 @@ void URLGrabber::slotKillPopupMenu()
{
if ( myMenu && myMenu->isVisible() )
{
- if ( myMenu->geometry().contains( TQCursor::pos() ) &&
+ if ( myMenu->tqgeometry().tqcontains( TQCursor::pos() ) &&
myPopupKillTimeout > 0 )
{
myPopupKillTimer->start( 1000 * myPopupKillTimeout, true );
@@ -400,7 +400,7 @@ ClipCommand::ClipCommand(const TQString &_command, const TQString &_description,
description(_description),
isEnabled(_isEnabled)
{
- int len = command.find(" ");
+ int len = command.tqfind(" ");
if (len == -1)
len = command.length();
diff --git a/klipper/urlgrabber.h b/klipper/urlgrabber.h
index e08092483..40d288b9a 100644
--- a/klipper/urlgrabber.h
+++ b/klipper/urlgrabber.h
@@ -39,7 +39,7 @@ struct ClipCommand;
typedef TQPtrList<ClipAction> ActionList;
typedef TQPtrListIterator<ClipAction> ActionListIterator;
-class URLGrabber : public QObject
+class URLGrabber : public TQObject
{
Q_OBJECT
@@ -132,7 +132,7 @@ public:
inline bool matches( const TQString& string ) {
int res = myRegExp.search( string ) ;
if ( res != -1 ) {
- myCapturedTexts = myRegExp.capturedTexts();
+ myCapturedTexts = myRegExp.tqcapturedTexts();
return true;
}
return false;
@@ -162,7 +162,7 @@ public:
private:
TQRegExp myRegExp;
- QStringList myCapturedTexts;
+ TQStringList myCapturedTexts;
TQString myDescription;
TQPtrList<ClipCommand> myCommands;
diff --git a/klipper/configdialog.h b/klipper/configdialog.h
index b7aa26659..219f5f6cf 100644
--- a/klipper/configdialog.h
+++ b/klipper/configdialog.h
@@ -42,7 +42,7 @@ class TQPushButton;
class TQDialog;
class ConfigDialog;
-class GeneralWidget : public QVBox
+class GeneralWidget : public TQVBox
{
Q_OBJECT
@@ -66,7 +66,7 @@ private:
// only for use inside ActionWidget
-class AdvancedWidget : public QVBox
+class AdvancedWidget : public TQVBox
{
Q_OBJECT
@@ -81,7 +81,7 @@ private:
KEditListBox *editListBox;
};
-class ActionWidget : public QVBox
+class ActionWidget : public TQVBox
{
Q_OBJECT
@@ -237,11 +237,11 @@ public:
ListView( ConfigDialog* configWidget, TQWidget *parent, const char *name )
: KListView( parent, name ), _configWidget( configWidget ),
_regExpEditor(0L) {}
- // TQListView has a weird idea of a sizeHint...
- virtual TQSize sizeHint () const {
- int w = minimumSizeHint().width();
+ // TQListView has a weird idea of a tqsizeHint...
+ virtual TQSize tqsizeHint () const {
+ int w = tqminimumSizeHint().width();
int h = header()->height();
- h += viewport()->sizeHint().height();
+ h += viewport()->tqsizeHint().height();
h += horizontalScrollBar()->height();
TQListViewItem *item = firstChild();